@@ -278,6 +278,16 @@ class TAppDay:
         stream.write("<hr align=center width=\"50%\">\n<p style=\'text-align:center;font-size:8pt\'>Generated by {}</p>".format(GCStrings.getString(130)))
         stream.write("</body></html>")
 
+    def write(self,stream,format='html',layout='list'):
+        if format=='plain':
+            self.formatPlainText(stream)
+        elif format=='rtf':
+            self.formatRtf(stream)
+        elif format=='xml':
+            self.formatXml(stream)
+        elif format=='html':
+            self.writeHtml(stream)
+
 def unittests():
     GCUT.info('result app')
     loc = GCLocation(data={
