@@ -98,6 +98,18 @@ class TMasaList:
         return 1
 
 
+    def writeXml(self,stream):
+        stream.write("<xml>\r\n")
+        stream.write("   <body title=\"Masa List\">\n\n")
+        stream.write("      <location>{}</location>\r\n".format(self.location.m_strFullName))
+        stream.write("      <masalist>\r\n")
+        for m in self.arr:
+            stream.write("         <masa name=\"{}\" year=\"{}\" start=\"{}\" end=\"{}\" />\r\n".format(m['masaName'], m['year'], str(m['start']), str(m['end'])))
+        stream.write("      </masalist>\r\n")
+        stream.write("      <author>{}</author>\r\n".format(GCStrings.getString(130)))
+        stream.write("   </body>\r\n</xml>\r\n")
+        return 1
+
     def writeHtml(self,stream):
         stream.write("<html>\n<head>\n<title>Masa List</title>\n\n")
         stream.write("<style>\n<!--\nbody {\n  font-family:Verdana;\n  font-size:11pt;\n}\n\ntd.hed {\n  font-size:11pt;\n  font-weight:bold;\n")
@@ -125,6 +137,16 @@ class TMasaList:
         stream.write("</body></html>")
         return 1
 
+    def write(self,stream,format='html'):
+        if format=='plain':
+            self.formatText(stream)
+        elif format=='rtf':
+            self.formatRtf(stream)
+        elif format=='xml':
+            self.writeXml(stream)
+        elif format=='html':
+            self.writeHtml(stream)
+
 
 def unittests():
     tm = TMasaList()
